@@ -1,6 +1,6 @@
 /* defs.h:
  * Copyright (c) 1995,1996 Sascha Demetrio
- * Copyright (c) 2009, 2015, 2016 Peter Pentchev
+ * Copyright (c) 2009, 2015, 2016, 2020 Peter Pentchev
  */
 
 /*
@@ -18,6 +18,14 @@
 #endif /* __GNUC__ */
 #endif /* __unused */
 
+#if !defined(fallthrough)
+#if defined(__GNUC__) && __GNUC__ >= 7
+#define fallthrough __attribute__((fallthrough))
+#else
+#define fallthrough /* fallthrough */
+#endif
+#endif
+
 /*
  * Buffer: (defaults)
  */
