@@ -2,7 +2,7 @@
  */
 
 /* Copyright (c) 1995,1996 Sascha Demetrio
- * Copyright (c) 2009, 2015, 2016, 2018 Peter Pentchev
+ * Copyright (c) 2009, 2015, 2016, 2018, 2020 Peter Pentchev
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -111,7 +111,7 @@ extern struct t_keynames_s {
   char *name;
 } t_keynames[];
 
-void (*error_msg)( const char *, ... ) __printflike(1, 2);
+extern void (*error_msg)( const char *, ... ) __printflike(1, 2);
   /* Pointer to the error message function.
    */
 
